@@ -10,6 +10,11 @@
 #               Ross N. Hoffman                 NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #               Hui Liu                         NOAA/NESDIS/STAR, CISESS at U. of Maryland
 #
+# History:
+#       2022            K.E. Lukens             Created/developed program.
+#       2023-04-14      K.E. Lukens             Finalized for upload to SAWC archive.
+#       2023-04-21      K.E. Lukens             Update: contour2d_orthomap color ranges no longer fixed. 
+#
 # Built with the following conda environment:
 #
 # name: bhoover-obs_match_3d
@@ -313,35 +318,55 @@ def contour2d_orthomap(datein,var2d,var2dstr,xvar,yvar,xvarstr,yvarstr,tname,uni
       title = ''
 
 	# set range of plotted colored contours
+    warnings.filterwarnings('ignore', category=RuntimeWarning)                # ignore warnings
+    varmax = np.nanmax(abs(var2d))
     if var2dstr.find('SD') != -1:
       ppcmap = "jet"
       pltmin = 1
       pltmax = 50
       stride = 5
+        # reassign color range max
+      if varmax!=np.nan and varmax<=60: pltmax=50
+      if varmax!=np.nan and varmax<=50: pltmax=40
+      if varmax!=np.nan and varmax<=40: pltmax=30
+      if varmax!=np.nan and varmax<=30: pltmax=20
+      if varmax!=np.nan and varmax<=20: pltmax=10
     elif var2dstr.find('Diff') != -1:
       ppcmap = "seismic"
       pltmin = -30
       pltmax = 30
       stride = 5
+        # reassign color range max
+      if varmax!=np.nan and varmax<=60: pltmax=50
+      if varmax!=np.nan and varmax<=50: pltmax=40
+      if varmax!=np.nan and varmax<=40: pltmax=30
+      if varmax!=np.nan and varmax<=30: pltmax=20
+      if varmax!=np.nan and varmax<=20: pltmax=10
+      pltmin = -pltmax
     elif var2dstr.find('Count') != -1:
       ppcmap = "jet"
       pltmin = 1
       pltmax = 100
         # reassign color range max
-      warnings.filterwarnings('ignore', category=RuntimeWarning)		# ignore warnings
-      varmax = np.nanmax(abs(var2d))
       if varmax!=np.nan and varmax>100000  : pltmax=100000
       if varmax!=np.nan and varmax<=100000: pltmax=10000
       if varmax!=np.nan and varmax<=10000: pltmax=1000
       if varmax!=np.nan and varmax<=1000: pltmax=100
       if varmax!=np.nan and varmax<=100: pltmax=10
       var2d  = np.where(var2d==np.nan,0,var2d)
-      del varmax
     else:
       ppcmap = "jet"
       pltmin = -50
       pltmax = 50
       stride = 5
+        # reassign color range max
+      if varmax!=np.nan and varmax<=60: pltmax=50
+      if varmax!=np.nan and varmax<=50: pltmax=40
+      if varmax!=np.nan and varmax<=40: pltmax=30
+      if varmax!=np.nan and varmax<=30: pltmax=20
+      if varmax!=np.nan and varmax<=20: pltmax=10
+      pltmin = -pltmax
+    del varmax
 
     originstr = 'lower'
 
@@ -2054,7 +2079,7 @@ def z_distr(vertbinsP,vertbinsH,Dlat,Dlon,tx,ty,tz,x_name,tname,xvarstr,zvarstr,
     ax2P1.set_ylabel(ylabel2, fontsize=fontaxis)
     
 	# legend
-    legP1 = axP1.legend(handles=custom_lines, loc='upper right', prop={'size': fontlegend-2})
+    legP1 = axP1.legend(handles=custom_lines, loc='lower left', prop={'size': fontlegend-2})
     legP2 = axP2.legend(loc='upper right', prop={'size': fontlegend-2})
     legP2 = ax2P2.legend(loc='upper center', prop={'size': fontlegend-2})
 
